# ApertureDB Client Python Module

This is the python client module for ApertureDB.

It provides a connector to AperetureDB instances using 
the open source connector for [VDMS](https://github.com/IntelLabs/vdms).

It also implements an Object-Model API to interact with 
elements in ApertureDB at the object level.
 
For more information, visit https://aperturedata.io

